==> roco-oil-card-settle-api-0.0.2-20200227.092854-10-sources.jar: com/roco/settle/api/service/EnterpriseTransferService.java <==
package com.roco.settle.api.service;

import com.roco.settle.api.entity.SettleEnterpriseServiceApplyItem;
import com.roco.settle.api.entity.enterprisetansfer.SettleEnterpriseTransferApply;
import com.roco.settle.api.entity.enterprisetansfer.SettleEnterpriseTransferApplyLog;
import com.roco.settle.api.request.base.CommonQueryPageRequest;
import com.roco.settle.api.request.base.CommonRequest;
import com.roco.settle.api.request.enterprisetansfer.*;
import com.roco.settle.api.response.base.CommonQueryPageResponse;
import com.roco.settle.api.response.base.CommonResponse;
import com.roco.settle.api.response.enterprisetansfer.EnterpriseTransferFileRes;

/**
 * @author Andrew
 * @create 2020/2/24 1:39 下午
 */
public interface EnterpriseTransferService {


    /**
     * 对公转账清单上传
     *
     * @param request
     * @return
     */
    CommonResponse<EnterpriseTransferFileRes> uploadFile(CommonRequest<EnterpriseTransferApplyFileReq> request);

    /**
     * 对公转账申请
     *
     * @param request
     * @return
     */
    CommonResponse<String> apply(CommonRequest<EnterpriseTransferApplyReq> request);


    /**
     * 分页查询
     *
     * @param request
     * @return
     */
    CommonQueryPageResponse<SettleEnterpriseTransferApply> page(CommonQueryPageRequest<EnterpriseTransferQueryReq> request);


    /**
     * 操作申请单
     *
     * @param request
     * @return
     */
    CommonResponse<Boolean> operate(CommonRequest<EnterpriseTransferOperateReq> request);


    /**
     * 详情
     * @param request
     * @return
     */
    CommonResponse<SettleEnterpriseTransferApply> detail(CommonRequest<EnterpriseTransferQueryReq> request);


    /**
     * 日志查询
     * @param request
     * @return
     */
    CommonQueryPageResponse<SettleEnterpriseTransferApplyLog> log(CommonQueryPageRequest<EnterpriseTransferQueryReq> request);


    /**
     * 查询清单
     * @param request
     * @return
     */
    CommonQueryPageResponse<SettleEnterpriseServiceApplyItem> itemPage(CommonQueryPageRequest<EnterpriseTransferQueryReq> request);




}

==> roco-oil-card-settle-api-1.3.0.20200403.035649-3-sources.jar: com/roco/settle/api/service/EnterpriseTransferService.java <==
package com.roco.settle.api.service;

import com.roco.settle.api.entity.SettleEnterpriseServiceApplyItem;
import com.roco.settle.api.entity.enterprisetansfer.SettleEnterpriseTransferApply;
import com.roco.settle.api.entity.enterprisetansfer.SettleEnterpriseTransferApplyLog;
import com.roco.settle.api.request.base.CommonQueryPageRequest;
import com.roco.settle.api.request.base.CommonRequest;
import com.roco.settle.api.request.enterprisetansfer.*;
import com.roco.settle.api.response.base.CommonQueryPageResponse;
import com.roco.settle.api.response.base.CommonResponse;
import com.roco.settle.api.response.enterprisetansfer.EnterpriseTransferFileRes;

/**
 * @author Andrew
 * @create 2020/2/24 1:39 下午
 */
public interface EnterpriseTransferService {


    /**
     * 对公转账清单上传
     *
     * @param request
     * @return
     */
    CommonResponse<EnterpriseTransferFileRes> uploadFile(CommonRequest<EnterpriseTransferApplyFileReq> request);

    /**
     * 对公转账申请
     *
     * @param request
     * @return
     */
    CommonResponse<String> apply(CommonRequest<EnterpriseTransferApplyReq> request);


    /**
     * 分页查询
     *
     * @param request
     * @return
     */
    CommonQueryPageResponse<SettleEnterpriseTransferApply> page(CommonQueryPageRequest<EnterpriseTransferQueryReq> request);


    /**
     * 操作申请单
     *
     * @param request
     * @return
     */
    CommonResponse<Boolean> operate(CommonRequest<EnterpriseTransferOperateReq> request);


    /**
     * 详情
     * @param request
     * @return
     */
    CommonResponse<SettleEnterpriseTransferApply> detail(CommonRequest<EnterpriseTransferQueryReq> request);


    /**
     * 日志查询
     * @param request
     * @return
     */
    CommonQueryPageResponse<SettleEnterpriseTransferApplyLog> log(CommonQueryPageRequest<EnterpriseTransferQueryReq> request);


    /**
     * 查询清单
     * @param request
     * @return
     */
    CommonQueryPageResponse<SettleEnterpriseServiceApplyItem> itemPage(CommonQueryPageRequest<EnterpriseTransferQueryReq> request);


    /**
     * 临时文件的分页查询
     * @param request
     * @return
     */
    CommonQueryPageResponse<SettleEnterpriseServiceApplyItem> tempFilePage(CommonQueryPageRequest<EnterpriseTransferQueryReq> request);


}
